%global _name   mesonbuild

Name:           meson
Version:        0.38.0
Release:        %mkrel 2
Summary:        High productivity build system
Group:          System/Packaging
License:        ASL 2.0
URL:            http://mesonbuild.com/
Source0:        https://github.com/mesonbuild/meson/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/mesonbuild/meson/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Patch0:         meson-0.38.0-mageiaify-macros.patch
BuildArch:      noarch

BuildRequires:  ninja
BuildRequires:  pkgconfig(python3)
BuildRequires:  pythonegg(3)(setuptools)

# Various languages
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  gcc-objc
BuildRequires:  gcc-objc++
BuildRequires:  java-devel
BuildRequires:  mono-core
BuildRequires:  pkgconfig(mono)
BuildRequires:  rust

# Various libs support
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  gtk-doc
BuildRequires:  itstool
BuildRequires:  locales-en
BuildRequires:  vala
BuildRequires:  vala-tools
BuildRequires:  boost-devel
BuildRequires:  gnustep-base-devel
BuildRequires:  gtest-devel
BuildRequires:  qtbase5-devel
BuildRequires:  wxgtk3.0-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3-gobject3
BuildRequires:  pythonegg(3)(cython)

Requires:       ninja

%description
Meson is a build system designed to optimize programmer productivity.
It aims to do this by providing simple, out-of-the-box support for
modern software development tools and practices, such as unit tests,
coverage reports, Valgrind, CCache and the like.

%prep
%autosetup -p1

find -type f -name '*.py' -executable -exec sed -i -e '1s|.*|#!%{__python3}|' {} ';'

%build
%py3_build

%install
%py3_install

# install meson rpm macro helper
install -D -m 0644 data/macros.%{name} %{buildroot}%{_rpmconfigdir}/macros.d/macros.%{name}

%check
# Lack of gmock.
rm -rf "test cases/frameworks/3 gmock/"

export MESON_PRINT_TEST_OUTPUT=1
%{__python3} ./run_tests.py

%files
%doc authors.txt contributing.txt README.md
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}conf
%{_bindir}/%{name}introspect
%{_bindir}/%{name}test
%{_bindir}/wraptool
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/%{name}conf.1.*
%{_mandir}/man1/%{name}test.1.*
%{_mandir}/man1/%{name}introspect.1.*
%{_mandir}/man1/wraptool.1.*
%{_rpmconfigdir}/macros.d/macros.%{name}
%{python3_sitelib}/%{_name}/
%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info/


%changelog
* Thu Feb 02 2017 daviddavid <daviddavid> 0.38.0-2.mga6
+ Revision: 1084599
- mageiaify the meson macros

* Wed Feb 01 2017 daviddavid <daviddavid> 0.38.0-1.mga6
+ Revision: 1084507
- new version: 0.38.0

* Tue Dec 20 2016 daviddavid <daviddavid> 0.37.1-1.mga6
+ Revision: 1076236
- new version: 0.37.1

* Mon Dec 19 2016 daviddavid <daviddavid> 0.37.0-1.mga6
+ Revision: 1076164
- new version: 0.37.0

* Sun Dec 04 2016 daviddavid <daviddavid> 0.36.0-2.mga6
+ Revision: 1071916
- print test output during build

* Thu Nov 17 2016 daviddavid <daviddavid> 0.36.0-1.mga6
+ Revision: 1068018
- new version: 0.36.0
- add BRs itstool and vala-tools

* Tue Oct 18 2016 daviddavid <daviddavid> 0.35.1-1.mga6
+ Revision: 1061569
- new version: 0.35.1
- remove merged upstream patch

* Thu Oct 06 2016 daviddavid <daviddavid> 0.35.0-2.mga6
+ Revision: 1059159
- add upstream patch to fix missing dependency in gnome.mkenums test

* Tue Oct 04 2016 daviddavid <daviddavid> 0.35.0-1.mga6
+ Revision: 1058585
- new version: 0.35.0

* Sun Sep 25 2016 daviddavid <daviddavid> 0.34.0-1.mga6
+ Revision: 1056136
- imported package meson (based on Fedora)

